LogRelevance enum
Values
- critical → const LogRelevance
-
const LogRelevance(Color(0xFF752626), 'CRITICAL') - error → const LogRelevance
-
const LogRelevance(Color(0xFFDA7373), 'ERROR') - warning → const LogRelevance
-
const LogRelevance(Color(0xFFC97C37), 'Warning') - information → const LogRelevance
-
const LogRelevance(Color(0xFFFFFFFF), 'Information')
Properties
- color → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - prefix → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LogRelevance> - A constant List of the values in this enum, in order of their declaration.