MethyleneImage enum

Inheritance
Available extensions

Values

logoStandard → const MethyleneImage
const MethyleneImage(x24: AssetImage('assets/images/logo/standard/24.png'), x56: AssetImage('assets/images/logo/standard/56.png'), x86: AssetImage('…
logoMinimal → const MethyleneImage
const MethyleneImage(x24: AssetImage('assets/images/logo/minimal/24.png'), x56: AssetImage('assets/images/logo/minimal/56.png'), x86: AssetImage('as…

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x124 AssetImage
final
x226 AssetImage
final
x24 AssetImage
final
x56 AssetImage
final
x86 AssetImage
final

Methods

getImage(double range) AssetImage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MethyleneImage>
A constant List of the values in this enum, in order of their declaration.