SideTabBarEntry class final
- Annotations
Constructors
- SideTabBarEntry({required String title})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
widget(
BuildContext context, {required double height, required double width, required bool active, required TabController controller, required int index}) → _SideTabBarEntryWidget
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited